@@ -5,7 +5,6 @@ from django.conf.urls.i18n import i18n_patterns
 from django.contrib import admin
 
 from mezzanine.core.views import direct_to_template
-from mezzanine.conf import settings
 
 
 admin.autodiscover()
@@ -15,19 +14,11 @@ admin.autodiscover()
 # to the project's homepage.
 
 urlpatterns = i18n_patterns("",
-
     # Change the admin prefix here to use an alternate URL for the
     # admin interface, which would be marginally more secure.
     ("^admin/", include(admin.site.urls)),
 )
 
-# Filebrowser admin media library.
-if getattr(settings, "PACKAGE_NAME_FILEBROWSER") in settings.INSTALLED_APPS:
-    urlpatterns += i18n_patterns("",
-        ("^admin/media-library/", include("%s.urls" %
-                                        settings.PACKAGE_NAME_FILEBROWSER)),
-    )
-
 urlpatterns += patterns('',
 
     # We don't want to presume how your homepage works, so here are a
